Learn R Programming

semlbci (version 0.11.5)

confint.semlbci: Confidence Intervals for a 'smelbci' Object

Description

Return the confidence intervals of the parameters in the output of semlbci().

Usage

# S3 method for semlbci
confint(object, parm, level = 0.95, ...)

Value

A two-column matrix of the confidence intervals.

Arguments

object

The output of semlbci().

parm

The parameters for which the confidence intervals are returned. Not used because parameters are defined by three or more columns (lhs, op, rhs, and group for multisample models).

level

Ignored. The level of confidence is determined when calling semlbci() and cannot be changed.

...

Optional arguments. Ignored.

Details

It returns the likelihood-based confidence intervals in the output of semlbci().

See Also

semlbci()

Examples

Run this code


library(lavaan)
mod <-
"
m ~ a*x
y ~ b*m
ab := a * b
"
fit_med <- sem(mod, simple_med, fixed.x = FALSE)
p_table <- parameterTable(fit_med)
p_table
lbci_med <- semlbci(fit_med,
                    pars = "ab :=")
lbci_med

confint(lbci_med)

Run the code above in your browser using DataLab