Learn R Programming

semlbci (version 0.11.5)

semlbci-package: semlbci: Likelihood-Based Confidence Interval in Structural Equation Models

Description

logo

Forms likelihood-based confidence intervals (LBCIs) for parameters in structural equation modeling, introduced in Cheung and Pesigan (2023) tools:::Rd_expr_doi("10.1080/10705511.2023.2183860"). Currently implements the algorithm illustrated by Pek and Wu (2018) tools:::Rd_expr_doi("10.1037/met0000163"), and supports the robust LBCI proposed by Falk (2018) tools:::Rd_expr_doi("10.1080/10705511.2017.1367254").

Arguments

Author

Maintainer: Shu Fai Cheung shufai.cheung@gmail.com (ORCID)

Other contributors:

See Also