syntax_to_i() converts a vector of strings, in lavaan syntax, to the
positions in the parameter table of a lavaan::lavaan fit object.
Each element in the vector should have left hand side (lhs),
operator (op), and/or right hand side (rhs). For example:all.x
For user-defined parameters, only lhs and op will be
interpreted. For example:
To denote a labelled parameters, such as "y ~ a*x", treat it as a
user-defined parameters and use :=, e.g., "a :=" in this example.
For multiple-group models, if a parameter is specified as in a
single-group models, then this parameter in all groups will be
selected. For example:all.x
To select the parameter in a specific group, "multiply" the
right-hand-side variable by the group number. For example:
To denote the parameters in more than one group, multiply the
right-hand side variable by a vector of number. For example:all.x
Elements that cannot be converted to a parameter in the parameter table will
be ignored.
Currently supports lavaan::lavaan outputs only.